@@ -1,11 +1,10 @@
-from django.http.response import HttpResponse, HttpResponseBadRequest
+from django.http.response import HttpResponse
 from django.utils import timezone
 from django.views.generic.base import View
 from django.views.generic.list import ListView
 from markdown import markdown
 from pico.conf import settings
 from pico.podcasts.models import Podcast, Page, Episode, Post
-from pico.podcasts.tasks import update_feed
 from pico.seo.mixins import SEOMixin, OpenGraphMixin
 import json
 import re
@@ -81,37 +80,6 @@ class PodcastListView(SEOMixin, OpenGraphMixin, ListView):
         }
 
 
-class PodcastPingView(View):
-    def get(self, request):
-        topic = request.GET.get('hub.topic')
-        mode = request.GET.get('hub.mode')
-        challenge = request.GET.get('hub.challenge')
-
-        for podcast in Podcast.objects.filter(
-            rss_feed_url=topic
-        ):
-            if mode in ('subscribe', 'unsubscribe') and challenge:
-                return HttpResponse(challenge)
-
-        return HttpResponseBadRequest('FAIL')
-
-    def post(self, request):
-        topic = request.META.get('HTTP_LINK')
-
-        if topic:
-            match = LINK_REGEX.match(topic)
-            if match is not None:
-                url = match.groups()[0]
-
-                for podcast in Podcast.objects.filter(
-                    rss_feed_url=url
-                ):
-                    update_feed.delay(podcast.pk, request.body)
-                    return HttpResponse('OK')
-
-        return HttpResponseBadRequest('FAIL')
-
-
 class ContentListView(View):
     def get_fields(self):
         if not hasattr(self, 'fields'):
@@ -133,12 +101,14 @@ class ContentListView(View):
 
     def get_querysets(self):
         limit = self.request.GET.get('limit', 'all')
-        querysets = [
-            Episode.objects.all(),
-            Post.objects.filter(
-                published__lte=timezone.now()
-            )
-        ]
+        episodes = Episode.objects.all()
+        posts = Post.objects.filter(published__lte=timezone.now())
+
+        if getattr(self.request, 'podcast', None):
+            episodes = episodes.filter(podcast=self.request.podcast)
+            posts = posts.filter(podcast=self.request.podcast)
+
+        querysets = [episodes, posts]
 
         if 'published_at' not in self.get_fields():
             querysets.append(
